api.authentication.v1.password.test_helpers.password_authenticate package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.password.test_helpers.password_authenticate package

## Submodules

## api.authentication.v1.password.test_helpers.password_authenticate.authenticate module

`api.authentication.v1.password.test_helpers.password_authenticate.authenticate.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/password/authenticate, respond with HTTP 403

`api.authentication.v1.password.test_helpers.password_authenticate.authenticate.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/password/authenticate, respond with HTTP 404

`api.authentication.v1.password.test_helpers.password_authenticate.authenticate.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/password/authenticate, respond with HTTP 200

`api.authentication.v1.password.test_helpers.password_authenticate.authenticate.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/password/authenticate, respond with HTTP 401

## Module contents